==> humhub-1.15.0-beta.2.tar.gz: humhub-1.15.0-beta.2/protected/humhub/modules/marketplace/messages/uz/base.php <==
<?php

return [
    'Settings' => 'Sozlamalar',
    '
Module successfully disabled!
' => '',
    '
Module successfully enabled!
' => '',
    '
No active Professional Edition license found!
' => '',
    '
The license could not be activated:
' => '',
    '
The license was successfully activated!

' => '',
    '
The license was successfully removed!

' => '',
    '--- Disable module: {moduleId} ---

' => '',
    '--- Enable module: {moduleId} ---

' => '',
    '<strong>Activate</strong> your Professional Edition' => '',
    '<strong>General</strong> Settings' => '',
    'A new update is available (HumHub %version%)!' => '',
    'Activate' => '',
    'Activate now' => '',
    'Activated' => '',
    'Add Licence Key' => '',
    'Add purchased module by licence key' => '',
    'After installing the required module, all you have to do is activate it. After that you can instantly start using the module or function. Please note that some modules need to be configured before use.' => '',
    'All' => '',
    'All {moduleId} module content will be deleted. Continue?' => '',
    'Allow module versions in beta status' => '',
    'Available Updates' => '',
    'Buy' => '',
    'Buy (%price%)' => '',
    'Categories' => '',
    'Changelog' => '',
    'Community' => '',
    'Configure' => '',
    'Could not connect to HumHub API!' => '',
    'Could not connect to HumHub API!
' => '',
    'Could not connect to licence server!' => '',
    'Could not extract module!' => '',
    'Could not find requested module!' => '',
    'Could not find the requested module!' => '',
    'Could not remove old module path!' => '',
    'Could not update licence. Error: ' => '',
    'Deprecated' => '',
    'Download of module failed!' => '',
    'Edit licence' => '',
    'Featured' => '',
    'Find all the modules you can add to your network in our HumHub Marketplace. Discover numerous add-ons and features that customize the software and give you the possibility to configure your network to your needs.' => '',
    'General Settings' => '',
    'Great!' => '',
    'If this Module is additionally marked as <strong>"Community"</strong> it is neither tested nor monitored by the HumHub project team.' => '',
    'Information' => '',
    'Install' => '',
    'Installed' => '',
    'Invalid module licence key!' => '',
    'Invalid module licence key!
' => '',
    'Latest version:' => '',
    'Learn more' => '',
    'Licence Key:' => '',
    'Licence key' => '',
    'Licenced for max. {number} users.' => '',
    'Licenced to:' => '',
    'License not found or expired. Please contact the module publisher.' => '',
    'Marketplace' => '',
    'Marketplace is disabled.' => '',
    'Max. users:' => '',
    'Module "{moduleName}" has been updated to version {newVersion} successfully.' => '',
    'Module <strong>activated</strong>' => '',
    'Module <strong>installed</strong>' => '',
    'Module configuration' => '',
    'Module directory %modulePath% is not writeable!' => '',
    'Module download failed! (%error%)' => '',
    'Module is <strong>installing...</strong>' => '',
    'Module licence added!' => '',
    'Module licence added!
' => '',
    'Module licence key cannot be empty!
' => '',
    'Module not found or activated!
' => '',
    'Module not found!
' => '',
    'More info' => '',
    'New' => '',
    'No compatible module version found!' => '',
    'No license key? Find out more about the {pro} or contact us.' => '',
    'No modules found.' => '',
    'No modules installed yet. Install some to enhance the functionality!' => '',
    'No purchased modules found!' => '',
    'Official' => '',
    'Ok' => '',
    'PROFESSIONAL EDITION' => '',
    'Partner' => '',
    'Professional Edition' => '',
    'Professional Edition is activated!' => '',
    'Register' => '',
    'Remove licence key' => '',
    'Save and update' => '',
    'Search' => '',
    'Search...' => '',
    'Stop updating' => '',
    'Tags' => '',
    'The HumHub project does not guarantee the functionality, quality or the continuous development of this Module.' => '',
    'Third-party' => '',
    'Third-party Modules are not covered by Professional Edition agreements.' => '',
    'Third-party disclaimer' => '',
    'This Module was developed by a third-party.' => '',
    'Try other keywords or remove filters.' => '',
    'Uninstalled' => '',
    'Update' => '',
    'Update all' => '',
    'Update successful' => '',
    'Upgrade to Professional Edition' => '',
    'Version:' => '',
    'We are almost there! As a final step, we recommend that you take a look at the module configuration, where you will find numerous configuration options, some of which are required.' => '',
    'Well done! To make the module available within your network, you will also need to activate it. Do you want to activate it now?' => '',
    'Well done! You have successful installed an activated the module!' => '',
    'Would you like to jump straight to it?' => '',
    'Your HumHub installation is up to date!' => '',
];

==> humhub-1.16.0-beta.2.tar.gz: humhub-1.16.0-beta.2/protected/humhub/modules/marketplace/messages/uz/base.php <==
<?php

return [
    'Settings' => 'Sozlamalar',
    '
Module successfully disabled!
' => '',
    '
Module successfully enabled!
' => '',
    '
No active Professional Edition license found!
' => '',
    '
The license could not be activated:
' => '',
    '
The license was successfully activated!

' => '',
    '
The license was successfully removed!

' => '',
    '--- Disable module: {moduleId} ---

' => '',
    '--- Enable module: {moduleId} ---

' => '',
    '<strong>Activate</strong> your Professional Edition' => '',
    '<strong>General</strong> Settings' => '',
    'A new update is available (HumHub %version%)!' => '',
    'Add Licence Key' => '',
    'Add purchased module by licence key' => '',
    'After installing the required module, all you have to do is activate it. After that you can instantly start using the module or function. Please note that some modules need to be configured before use.' => '',
    'All' => '',
    'All modules' => '',
    'All {moduleId} module content will be deleted. Continue?' => '',
    'Allow module versions in beta status' => '',
    'Available Updates' => '',
    'Buy' => '',
    'Buy (%price%)' => '',
    'Categories' => '',
    'Changelog' => '',
    'Community' => '',
    'Configure' => '',
    'Could not connect to HumHub API!' => '',
    'Could not connect to HumHub API!
' => '',
    'Could not connect to licence server!' => '',
    'Could not extract module!' => '',
    'Could not find requested module!' => '',
    'Could not find the requested module!' => '',
    'Could not remove old module path!' => '',
    'Could not update licence. Error: ' => '',
    'Deprecated' => '',
    'Download of module failed!' => '',
    'Edit licence' => '',
    'Enable' => '',
    'Enable now' => '',
    'Enabled' => '',
    'Featured' => '',
    'Find all the modules you can add to your network in our HumHub Marketplace. Discover numerous add-ons and features that customize the software and give you the possibility to configure your network to your needs.' => '',
    'General Settings' => '',
    'Great!' => '',
    'If this Module is additionally marked as <strong>"Community"</strong> it is neither tested nor monitored by the HumHub project team.' => '',
    'Information' => '',
    'Install' => '',
    'Installed' => '',
    'Invalid module licence key!' => '',
    'Invalid module licence key!
' => '',
    'Latest version:' => '',
    'Learn more' => '',
    'Licence Key:' => '',
    'Licence key' => '',
    'Licenced for max. {number} users.' => '',
    'Licenced to:' => '',
    'License not found or expired. Please contact the module publisher.' => '',
    'Marketplace' => '',
    'Marketplace is disabled.' => '',
    'Max. users:' => '',
    'Module "{moduleName}" has been updated to version {newVersion} successfully.' => '',
    'Module <strong>enabled</strong>' => '',
    'Module <strong>installed</strong>' => '',
    'Module Administration' => '',
    'Module configuration' => '',
    'Module directory %modulePath% is not writeable!' => '',
    'Module download failed! (%error%)' => '',
    'Module is <strong>installing...</strong>' => '',
    'Module licence added!' => '',
    'Module licence added!
' => '',
    'Module licence key cannot be empty!
' => '',
    'Module not found or enabled!
' => '',
    'Module not found!
' => '',
    'More info' => '',
    'New' => '',
    'No compatible module version found!' => '',
    'No license key? Find out more about the {pro} or contact us.' => '',
    'No modules found.' => '',
    'No modules installed yet. Install some to enhance the functionality!' => '',
    'No purchased modules found!' => '',
    'No, thank you!' => '',
    'Official' => '',
    'Ok' => '',
    'PROFESSIONAL EDITION' => '',
    'Partner' => '',
    'Professional Edition' => '',
    'Professional Edition is activated!' => '',
    'Register' => '',
    'Remove licence key' => '',
    'Save and update' => '',
    'Search' => '',
    'Search...' => '',
    'Stop updating' => '',
    'Tags' => '',
    'The HumHub project does not guarantee the functionality, quality or the continuous development of this Module.' => '',
    'Third-party' => '',
    'Third-party Modules are not covered by Professional Edition agreements.' => '',
    'Third-party disclaimer' => '',
    'This Module was developed by a third-party.' => '',
    'Try other keywords or remove filters.' => '',
    'Uninstalled' => '',
    'Update' => '',
    'Update all' => '',
    'Update successful' => '',
    'Upgrade to Professional Edition' => '',
    'Version:' => '',
    'We are almost there! As a final step, we recommend that you take a look at the module configuration, where you will find numerous configuration options, some of which are required.' => '',
    'Well done! To make the module available within your network, you will also need to enable it. Do you want to enable it now?' => '',
    'Well done! You have successfully installed and enabled the module!' => '',
    'Without category' => '',
    'Would you like to jump straight to it?' => '',
    'Your HumHub installation is up to date!' => '',
];
